# yamconv

`yamconv` coverts a machine learning dataset from one format to another format.

## Usage

```sh
yamconv -c converter_name -i input_file -o ouput_file -v
```

* `-c`: converter name
* `-i`: input file path
* `-o`: output file path
* `-v`: verbose

## Supported converters

The following are the supported converters:

* `fasttext2sqlite`: fastText text file to SQLite database file
* `sqlite2fasttext`: SQLite database file to fastText text file

## Profesional services
If you need any supporting resources or consultancy services from YAM AI Machinery, please find us at:

* https://www.yam.ai
* https://twitter.com/theYAMai
* https://www.linkedin.com/company/yamai
* https://www.facebook.com/theYAMai
* https://github.com/yam-ai
* https://hub.docker.com/u/yamai